@@ -26,7 +26,7 @@ copyright = "2020, Open Contracting Partnership"
 author = "Open Contracting Partnership"
 
 # The short X.Y version
-version = "0.0.3"
+version = "0.0.4"
 # The full version, including alpha/beta/rc tags
 release = version
 
@@ -38,6 +38,7 @@ release = version
 # ones.
 extensions = [
     "sphinx.ext.autodoc",
+    "sphinx.ext.intersphinx",
     "sphinx.ext.viewcode",
     "sphinxcontrib.opencontracting",
 ]
@@ -56,7 +57,7 @@ exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
 # The theme to use for HTML and HTML Help pages.  See the documentation for
 # a list of builtin themes.
 #
-html_theme = "default"
+html_theme = "furo"
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
@@ -66,23 +67,18 @@ html_static_path = []
 
 # -- Extension configuration -------------------------------------------------
 
-# Needed for ReadTheDocs (Sphinx 1.8).
-master_doc = "index"
-
 autodoc_default_options = {
     "members": None,
+    "member-order": "bysource",
 }
-autodoc_member_order = "bysource"
+autodoc_typehints = "description"
+autodoc_type_aliases = {}
 
-on_rtd = os.environ.get("READTHEDOCS", None) == "True"
-
-if not on_rtd:  # only import and set the theme if we're building docs locally
-    import sphinx_rtd_theme
-
-    html_theme = "sphinx_rtd_theme"
-    html_theme_path = [sphinx_rtd_theme.get_html_theme_path()]
+intersphinx_mapping = {
+    "python": ("https://docs.python.org/3", None),
+}
 
 extension_versions = {
-    'bids': 'v1.1.5',
-    'lots': 'v1.1.5',
+    "bids": "v1.1.5",
+    "lots": "v1.1.5",
 }
